summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2010-06-22 13:03:32 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2010-06-25 20:06:40 -0500
commitef3831a1fe0318b68bc6a21996fdb1589eb5c354 (patch)
tree5c975e931aa93fb829038593e020288d9b5e9a64
parent5feb87cd0edeb831722f4674334d1e90ca60bffd (diff)
downloadlibpng-1.5.0beta30.tar.gz
[devel] Imported from libpng-1.5.0beta30.tarv1.5.0beta30
-rw-r--r--ANNOUNCE21
-rw-r--r--CHANGES2
-rw-r--r--CMakeLists.txt2
-rw-r--r--INSTALL4
-rw-r--r--LICENSE4
-rw-r--r--README2
-rwxr-xr-xconfigure22
-rw-r--r--configure.ac4
-rw-r--r--example.c2
-rw-r--r--libpng-1.5.0beta30.txt (renamed from libpng-1.5.0beta29.txt)10
-rw-r--r--libpng.322
-rw-r--r--libpngpf.34
-rw-r--r--png.52
-rw-r--r--png.c8
-rw-r--r--png.h20
-rw-r--r--pngconf.h2
-rw-r--r--pngdebug.h2
-rw-r--r--pngerror.c2
-rw-r--r--pngget.c2
-rw-r--r--pnginfo.h2
-rw-r--r--pngmem.c2
-rw-r--r--pngpread.c16
-rw-r--r--pngpriv.h2
-rw-r--r--pngread.c2
-rw-r--r--pngrio.c2
-rw-r--r--pngrtran.c2
-rw-r--r--pngrutil.c20
-rw-r--r--pngset.c2
-rw-r--r--pngstruct.h2
-rw-r--r--pngtest.c4
-rw-r--r--pngtrans.c2
-rw-r--r--pngwio.c2
-rw-r--r--pngwrite.c2
-rw-r--r--pngwtran.c2
-rw-r--r--pngwutil.c2
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt12
-rwxr-xr-xscripts/libpng-config-head.in2
-rw-r--r--scripts/libpng.pc.in2
-rw-r--r--scripts/makefile.ne12bsd2
-rw-r--r--scripts/makefile.netbsd2
-rw-r--r--scripts/makefile.openbsd2
-rwxr-xr-xscripts/options.awk2
-rw-r--r--scripts/pnglibconf.dfa2
-rw-r--r--scripts/pnglibconf.h4
-rw-r--r--scripts/pngwin.def2
-rw-r--r--scripts/pngwin.dfn2
-rw-r--r--scripts/sym.dfn2
-rw-r--r--scripts/symbols.def2
-rw-r--r--scripts/symbols.dfn2
-rw-r--r--scripts/vers.dfn2
52 files changed, 134 insertions, 115 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index 946002147..8de92803e 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
-Libpng 1.5.0beta29 - June 21, 2010
+Libpng 1.5.0beta30 - June 22, 2010
This is not intended to be a public release. It will be replaced
within a few weeks by a public version or by another test version.
@@ -9,20 +9,20 @@ Files available for download:
Source files with LF line endings (for Unix/Linux) and with a
"configure" script
- 1.5.0beta29.tar.xz (LZMA-compressed, recommended)
- 1.5.0beta29.tar.gz
- 1.5.0beta29.tar.bz2
+ 1.5.0beta30.tar.xz (LZMA-compressed, recommended)
+ 1.5.0beta30.tar.gz
+ 1.5.0beta30.tar.bz2
Source files with CRLF line endings (for Windows), without the
"configure" script
- lp150b29.zip
- lp150b29.7z
+ lp150b30.zip
+ lp150b30.7z
Other information:
- 1.5.0beta29-README.txt
- 1.5.0beta29-LICENSE.txt
+ 1.5.0beta30-README.txt
+ 1.5.0beta30-LICENSE.txt
Changes since the last public release (1.4.1):
@@ -225,7 +225,7 @@ version 1.5.0beta24 [May 7, 2010]
offset of the png_ptr->rowbuf pointer into png_ptr->big_row_buf.
Added more blank lines for readability.
-version 1.5.0beta25 [June 21, 2010]
+version 1.5.0beta25 [June 22, 2010]
In pngpread.c: png_push_have_row() add check for new_row > height
Removed the now-redundant check for out-of-bounds new_row from example.c
@@ -244,6 +244,9 @@ version 1.5.0beta29 [June 21, 2010]
Revised scripts/options.awk to work on Sunos (but still doesn't work)
Added comment to options.awk and contrib/pngminim/*/makefile to try nawk.
+version 1.5.0beta30 [June 22, 2010]
+ Stop memory leak when reading a malformed sCAL chunk.
+
Send comments/corrections/commendations to png-mng-implement at lists.sf.net:
(subscription required; visit
https://lists.sourceforge.net/lists/listinfo/png-mng-implement
diff --git a/CHANGES b/CHANGES
index 6a413c6d9..670706979 100644
--- a/CHANGES
+++ b/CHANGES
@@ -2726,6 +2726,8 @@ version 1.5.0beta29 [June 21, 2010]
Revised scripts/options.awk to work on Sunos (but still doesn't work)
Added comment to options.awk and contrib/pngminim/*/makefile to try nawk.
+version 1.5.0beta30 [June 22, 2010]
+ Stop memory leak when reading a malformed sCAL chunk.
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 733cf3c85..ee3d74a58 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -207,7 +207,7 @@ configure_file(${CMAKE_CURRENT_SOURCE_DIR}/libpng-config.in
# SET UP LINKS
if(PNG_SHARED)
set_target_properties(${PNG_LIB_NAME} PROPERTIES
-# VERSION 15.${PNGLIB_RELEASE}.1.5.0beta29
+# VERSION 15.${PNGLIB_RELEASE}.1.5.0beta30
VERSION 15.${PNGLIB_RELEASE}.0
SOVERSION 15
CLEAN_DIRECT_OUTPUT 1)
diff --git a/INSTALL b/INSTALL
index 473045665..ec6e43429 100644
--- a/INSTALL
+++ b/INSTALL
@@ -1,5 +1,5 @@
-Installing libpng version 1.5.0beta29 - June 21, 2010
+Installing libpng version 1.5.0beta30 - June 22, 2010
On Unix/Linux and similar systems, you can simply type
@@ -46,7 +46,7 @@ to have access to the zlib.h and zconf.h include files that
correspond to the version of zlib that's installed.
You can rename the directories that you downloaded (they
-might be called "libpng-1.5.0beta29" or "libpng15" and "zlib-1.2.3"
+might be called "libpng-1.5.0beta30" or "libpng15" and "zlib-1.2.3"
or "zlib123") so that you have directories called "zlib" and "libpng".
Your directory structure should look like this:
diff --git a/LICENSE b/LICENSE
index 4cd189d0f..3458dc3ec 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.0beta29, June 21, 2010, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.0beta30, June 22, 2010, are
Copyright (c) 2004, 2006-2007 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-June 21, 2010
+June 22, 2010
diff --git a/README b/README
index 484810cb1..d94746a76 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.0beta29 - June 21, 2010 (shared library 15.0)
+README for libpng version 1.5.0beta30 - June 22, 2010 (shared library 15.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/configure b/configure
index f9c8fe2ae..0ff3db94a 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
#! /bin/sh
# Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.65 for libpng 1.5.0beta29.
+# Generated by GNU Autoconf 2.65 for libpng 1.5.0beta30.
#
# Report bugs to <png-mng-implement@lists.sourceforge.net>.
#
@@ -701,8 +701,8 @@ MAKEFLAGS=
# Identity of this package.
PACKAGE_NAME='libpng'
PACKAGE_TARNAME='libpng'
-PACKAGE_VERSION='1.5.0beta29'
-PACKAGE_STRING='libpng 1.5.0beta29'
+PACKAGE_VERSION='1.5.0beta30'
+PACKAGE_STRING='libpng 1.5.0beta30'
PACKAGE_BUGREPORT='png-mng-implement@lists.sourceforge.net'
PACKAGE_URL=''
@@ -1432,7 +1432,7 @@ if test "$ac_init_help" = "long"; then
# Omit some internal or obsolete options to make the list less imposing.
# This message is too long to be a string in the A/UX 3.1 sh.
cat <<_ACEOF
-\`configure' configures libpng 1.5.0beta29 to adapt to many kinds of systems.
+\`configure' configures libpng 1.5.0beta30 to adapt to many kinds of systems.
Usage: $0 [OPTION]... [VAR=VALUE]...
@@ -1502,7 +1502,7 @@ fi
if test -n "$ac_init_help"; then
case $ac_init_help in
- short | recursive ) echo "Configuration of libpng 1.5.0beta29:";;
+ short | recursive ) echo "Configuration of libpng 1.5.0beta30:";;
esac
cat <<\_ACEOF
@@ -1607,7 +1607,7 @@ fi
test -n "$ac_init_help" && exit $ac_status
if $ac_init_version; then
cat <<\_ACEOF
-libpng configure 1.5.0beta29
+libpng configure 1.5.0beta30
generated by GNU Autoconf 2.65
Copyright (C) 2009 Free Software Foundation, Inc.
@@ -2032,7 +2032,7 @@ cat >config.log <<_ACEOF
This file contains any messages produced by compilers while
running configure, to aid debugging if configure makes a mistake.
-It was created by libpng $as_me 1.5.0beta29, which was
+It was created by libpng $as_me 1.5.0beta30, which was
generated by GNU Autoconf 2.65. Invocation command line was
$ $0 $@
@@ -2840,7 +2840,7 @@ fi
# Define the identity of the package.
PACKAGE='libpng'
- VERSION='1.5.0beta29'
+ VERSION='1.5.0beta30'
cat >>confdefs.h <<_ACEOF
@@ -2904,7 +2904,7 @@ fi
-PNGLIB_VERSION=1.5.0beta29
+PNGLIB_VERSION=1.5.0beta30
PNGLIB_MAJOR=1
PNGLIB_MINOR=5
PNGLIB_RELEASE=0
@@ -12119,7 +12119,7 @@ cat >>$CONFIG_STATUS <<\_ACEOF || ac_write_fail=1
# report actual input values of CONFIG_FILES etc. instead of their
# values after options handling.
ac_log="
-This file was extended by libpng $as_me 1.5.0beta29, which was
+This file was extended by libpng $as_me 1.5.0beta30, which was
generated by GNU Autoconf 2.65. Invocation command line was
CONFIG_FILES = $CONFIG_FILES
@@ -12185,7 +12185,7 @@ _ACEOF
cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
ac_cs_version="\\
-libpng config.status 1.5.0beta29
+libpng config.status 1.5.0beta30
configured by $0, generated by GNU Autoconf 2.65,
with options \\"\$ac_cs_config\\"
diff --git a/configure.ac b/configure.ac
index e14379a28..9c6eeb837 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,12 +18,12 @@ AC_PREREQ(2.59)
dnl Version number stuff here:
-AC_INIT([libpng], [1.5.0beta29], [png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng], [1.5.0beta30], [png-mng-implement@lists.sourceforge.net])
AM_INIT_AUTOMAKE
dnl stop configure from automagically running automake
AM_MAINTAINER_MODE
-PNGLIB_VERSION=1.5.0beta29
+PNGLIB_VERSION=1.5.0beta30
PNGLIB_MAJOR=1
PNGLIB_MINOR=5
PNGLIB_RELEASE=0
diff --git a/example.c b/example.c
index 1cc234bff..9f4c48605 100644
--- a/example.c
+++ b/example.c
@@ -2,7 +2,7 @@
#if 0 /* in case someone actually tries to compile this */
/* example.c - an example of using libpng
- * Last changed in libpng 1.5.0 [June 21, 2010]
+ * Last changed in libpng 1.5.0 [June 22, 2010]
* This file has been placed in the public domain by the authors.
* Maintained 1998-2010 Glenn Randers-Pehrson
* Maintained 1996, 1997 Andreas Dilger)
diff --git a/libpng-1.5.0beta29.txt b/libpng-1.5.0beta30.txt
index fd88e26b1..590ea0c23 100644
--- a/libpng-1.5.0beta29.txt
+++ b/libpng-1.5.0beta30.txt
@@ -1,6 +1,6 @@
libpng.txt - A description on how to use and modify libpng
- libpng version 1.5.0beta29 - June 21, 2010
+ libpng version 1.5.0beta30 - June 22, 2010
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2009 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.0beta29 - June 21, 2010
+ libpng versions 0.97, January 1998, through 1.5.0beta30 - June 22, 2010
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2009 Glenn Randers-Pehrson
@@ -906,7 +906,7 @@ things.
As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
added. It expands the sample depth without changing tRNS to alpha.
-As of libpng version 1.5.0beta29, not all possible expansions are supported.
+As of libpng version 1.5.0beta30, not all possible expansions are supported.
In the following table, the 01 means grayscale with depth<8, 31 means
indexed with depth<8, other numerals represent the color type, "T" means
@@ -3301,13 +3301,13 @@ Other rules can be inferred by inspecting the libpng source.
XIII. Y2K Compliance in libpng
-June 21, 2010
+June 22, 2010
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.0beta29 are Y2K compliant. It is my belief that earlier
+upward through 1.5.0beta30 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer that
diff --git a/libpng.3 b/libpng.3
index da3c6dcfa..4291ca16e 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "June 21, 2010"
+.TH LIBPNG 3 "June 22, 2010"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.0beta29
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.0beta30
.SH SYNOPSIS
\fI\fB
@@ -789,7 +789,7 @@ Following is a copy of the libpng.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng.txt - A description on how to use and modify libpng
- libpng version 1.5.0beta29 - June 21, 2010
+ libpng version 1.5.0beta30 - June 22, 2010
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2009 Glenn Randers-Pehrson
@@ -800,7 +800,7 @@ libpng.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.0beta29 - June 21, 2010
+ libpng versions 0.97, January 1998, through 1.5.0beta30 - June 22, 2010
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2009 Glenn Randers-Pehrson
@@ -1695,7 +1695,7 @@ things.
As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
added. It expands the sample depth without changing tRNS to alpha.
-As of libpng version 1.5.0beta29, not all possible expansions are supported.
+As of libpng version 1.5.0beta30, not all possible expansions are supported.
In the following table, the 01 means grayscale with depth<8, 31 means
indexed with depth<8, other numerals represent the color type, "T" means
@@ -4090,13 +4090,13 @@ Other rules can be inferred by inspecting the libpng source.
.SH XIII. Y2K Compliance in libpng
-June 21, 2010
+June 22, 2010
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.0beta29 are Y2K compliant. It is my belief that earlier
+upward through 1.5.0beta30 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer that
@@ -4275,7 +4275,7 @@ the first widely used release:
1.4.1 14 10401 14.so.14.1[.0]
1.4.2 14 10402 14.so.14.2[.0]
1.4.3 14 10403 14.so.14.3[.0]
- 1.5.0beta01-29 15 10500 15.so.15.0[.0]
+ 1.5.0beta01-30 15 10500 15.so.15.0[.0]
Henceforth the source version will match the shared-library minor
and patch numbers; the shared-library major version number will be
@@ -4332,7 +4332,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.5.0beta29 - June 21, 2010:
+Libpng version 1.5.0beta30 - June 22, 2010:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -4355,7 +4355,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.0beta29, June 21, 2010, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.0beta30, June 22, 2010, are
Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -4454,7 +4454,7 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-June 21, 2010
+June 22, 2010
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index 01e669b6a..6d7ce4a94 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "June 21, 2010"
+.TH LIBPNGPF 3 "June 22, 2010"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.0beta29
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.0beta30
(private functions)
.SH SYNOPSIS
\fB#include \fI"pngpriv.h"
diff --git a/png.5 b/png.5
index 1c5faf9a0..c9286b0bd 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "June 21, 2010"
+.TH PNG 5 "June 22, 2010"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/pngconf.h b/pngconf.h
index 1ec34aa39..be00e7218 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.5.0beta29 - June 21, 2010
+ * libpng version 1.5.0beta30 - June 22, 2010
*
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngdebug.h b/pngdebug.h
index 6e1e68400..3ac67ba57 100644
--- a/pngdebug.h
+++ b/pngdebug.h
@@ -5,7 +5,7 @@
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
- * Last changed in libpng version 1.5.0 - June 21, 2010
+ * Last changed in libpng version 1.5.0 - June 22, 2010
*
* This code is released under the libpng license.
* For conditions of distribution and use, see the disclaimer
diff --git a/pngerror.c b/pngerror.c
index 745b2f417..72d500bb9 100644
--- a/pngerror.c
+++ b/pngerror.c
@@ -1,7 +1,7 @@
/* pngerror.c - stub functions for i/o and memory allocation
*
- * Last changed in libpng 1.5.0 [June 21, 2010]
+ * Last changed in libpng 1.5.0 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngget.c b/pngget.c
index 0ae0c8954..9f5eb3bc2 100644
--- a/pngget.c
+++ b/pngget.c
@@ -1,7 +1,7 @@
/* pngget.c - retrieval of values from info struct
*
- * Last changed in libpng 1.4.1 [June 21, 2010]
+ * Last changed in libpng 1.4.1 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pnginfo.h b/pnginfo.h
index 220f86cb7..e0f5a43c3 100644
--- a/pnginfo.h
+++ b/pnginfo.h
@@ -5,7 +5,7 @@
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
- * Last changed in libpng version 1.5.0 - June 21, 2010
+ * Last changed in libpng version 1.5.0 - June 22, 2010
*
* This code is released under the libpng license.
* For conditions of distribution and use, see the disclaimer
diff --git a/pngmem.c b/pngmem.c
index 9a5d3b97c..b54d465a4 100644
--- a/pngmem.c
+++ b/pngmem.c
@@ -1,7 +1,7 @@
/* pngmem.c - stub functions for memory allocation
*
- * Last changed in libpng 1.5.0 [June 21, 2010]
+ * Last changed in libpng 1.5.0 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngpread.c b/pngpread.c
index 0568b88af..c06b9afd8 100644
--- a/pngpread.c
+++ b/pngpread.c
@@ -1,7 +1,7 @@
/* pngpread.c - read a png file in push mode
*
- * Last changed in libpng 1.5.0 [June 21, 2010]
+ * Last changed in libpng 1.5.0 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -837,7 +837,7 @@ png_process_IDAT_data(png_structp png_ptr, png_bytep buffer,
png_size_t buffer_length)
{
/* The caller checks for a non-zero buffer length. */
- if (!(buffer_length > 0) || buffer == 0)
+ if (!(buffer_length > 0) || buffer == NULL)
png_error(png_ptr, "No IDAT data (internal error)");
/* This routine must process all the data it has been given
@@ -856,7 +856,7 @@ png_process_IDAT_data(png_structp png_ptr, png_bytep buffer,
int ret;
/* We have data for zlib, but we must check that zlib
- * has somewhere to put the results. It doesn't matter
+ * has someplace to put the results. It doesn't matter
* if we don't expect any results -- it may be the input
* data is just the LZ end code.
*/
@@ -870,11 +870,11 @@ png_process_IDAT_data(png_structp png_ptr, png_bytep buffer,
}
/* Using Z_SYNC_FLUSH here means that an unterminated
- * LZ stream can still be handled (a stream with a missing
- * end code), otherwise (Z_NO_FLUSH) a future zlib
- * implementation might defer output and, therefore,
- * change the current behavior. (See comments in inflate.c
- * for why this doesn't happen at present with zlib 1.2.5.)
+ * LZ stream (a stream with a missing end code) can still
+ * be handled, otherwise (Z_NO_FLUSH) a future zlib
+ * implementation might defer output and therefore
+ * change the current behavior (see comments in inflate.c
+ * for why this doesn't happen at present with zlib 1.2.5).
*/
ret = inflate(&png_ptr->zstream, Z_SYNC_FLUSH);
diff --git a/pngpriv.h b/pngpriv.h
index 8914f9f6f..565654bcc 100644
--- a/pngpriv.h
+++ b/pngpriv.h
@@ -1,7 +1,7 @@
/* pngpriv.h - private declarations for use inside libpng
*
- * libpng version 1.5.0beta29 - June 21, 2010
+ * libpng version 1.5.0beta30 - June 22, 2010
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngread.c b/pngread.c
index f858abe18..86d6dd461 100644
--- a/pngread.c
+++ b/pngread.c
@@ -1,7 +1,7 @@
/* pngread.c - read a PNG file
*
- * Last changed in libpng 1.5.0 [June 21, 2010]
+ * Last changed in libpng 1.5.0 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngrio.c b/pngrio.c
index 092c3bc84..57b3faf95 100644
--- a/pngrio.c
+++ b/pngrio.c
@@ -1,7 +1,7 @@
/* pngrio.c - functions for data input
*
- * Last changed in libpng 1.5.0 [June 21, 2010]
+ * Last changed in libpng 1.5.0 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngrtran.c b/pngrtran.c
index 29245978f..572537beb 100644
--- a/pngrtran.c
+++ b/pngrtran.c
@@ -1,7 +1,7 @@
/* pngrtran.c - transforms the data in a row for PNG readers
*
- * Last changed in libpng 1.5.0 [June 21, 2010]
+ * Last changed in libpng 1.5.0 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngrutil.c b/pngrutil.c
index e3d788e8f..dad552cd2 100644
--- a/pngrutil.c
+++ b/pngrutil.c
@@ -1,7 +1,7 @@
/* pngrutil.c - utilities to read a PNG file
*
- * Last changed in libpng 1.4.1 [June 21, 2010]
+ * Last changed in libpng 1.4.1 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -1891,6 +1891,7 @@ png_handle_sCAL(png_structp png_ptr, png_infop info_ptr, png_uint_32 length)
if (png_ptr->chunkdata == NULL)
{
png_warning(png_ptr, "Out of memory while processing sCAL chunk");
+ png_crc_finish(png_ptr, length);
return;
}
@@ -1913,6 +1914,8 @@ png_handle_sCAL(png_structp png_ptr, png_infop info_ptr, png_uint_32 length)
if (*vp)
{
png_warning(png_ptr, "malformed width string in sCAL chunk");
+ png_free(png_ptr, png_ptr->chunkdata);
+ png_ptr->chunkdata = NULL;
return;
}
#else
@@ -1922,6 +1925,8 @@ png_handle_sCAL(png_structp png_ptr, png_infop info_ptr, png_uint_32 length)
if (swidth == NULL)
{
png_warning(png_ptr, "Out of memory while processing sCAL chunk width");
+ png_free(png_ptr, png_ptr->chunkdata);
+ png_ptr->chunkdata = NULL;
return;
}
@@ -1937,8 +1942,7 @@ png_handle_sCAL(png_structp png_ptr, png_infop info_ptr, png_uint_32 length)
if (png_ptr->chunkdata + slength < ep)
{
png_warning(png_ptr, "Truncated sCAL chunk");
-#if defined(PNG_FIXED_POINT_SUPPORTED) && \
- !defined(PNG_FLOATING_POINT_SUPPORTED)
+#if defined(PNG_FIXED_POINT_SUPPORTED) && !defined(PNG_FLOATING_POINT_SUPPORTED)
png_free(png_ptr, swidth);
#endif
png_free(png_ptr, png_ptr->chunkdata);
@@ -1952,6 +1956,11 @@ png_handle_sCAL(png_structp png_ptr, png_infop info_ptr, png_uint_32 length)
if (*vp)
{
png_warning(png_ptr, "malformed height string in sCAL chunk");
+ png_free(png_ptr, png_ptr->chunkdata);
+ png_ptr->chunkdata = NULL;
+#if defined(PNG_FIXED_POINT_SUPPORTED) && !defined(PNG_FLOATING_POINT_SUPPORTED)
+ png_free(png_ptr, swidth);
+#endif
return;
}
@@ -1962,6 +1971,11 @@ png_handle_sCAL(png_structp png_ptr, png_infop info_ptr, png_uint_32 length)
if (sheight == NULL)
{
png_warning(png_ptr, "Out of memory while processing sCAL chunk height");
+ png_free(png_ptr, png_ptr->chunkdata);
+ png_ptr->chunkdata = NULL;
+#if defined(PNG_FIXED_POINT_SUPPORTED) && !defined(PNG_FLOATING_POINT_SUPPORTED)
+ png_free(png_ptr, swidth);
+#endif
return;
}
diff --git a/pngset.c b/pngset.c
index aa5bbd78c..f15abec63 100644
--- a/pngset.c
+++ b/pngset.c
@@ -1,7 +1,7 @@
/* pngset.c - storage of image information into info struct
*
- * Last changed in libpng 1.5.0 [June 21, 2010]
+ * Last changed in libpng 1.5.0 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngstruct.h b/pngstruct.h
index bec5b6967..b478d79ac 100644
--- a/pngstruct.h
+++ b/pngstruct.h
@@ -5,7 +5,7 @@
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
- * Last changed in libpng version 1.5.0 - June 21, 2010
+ * Last changed in libpng version 1.5.0 - June 22, 2010
*
* This code is released under the libpng license.
* For conditions of distribution and use, see the disclaimer
diff --git a/pngtest.c b/pngtest.c
index 9067faf4c..a74c07e12 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1,7 +1,7 @@
/* pngtest.c - a simple test program to test libpng
*
- * Last changed in libpng 1.5.0 [June 21, 2010]
+ * Last changed in libpng 1.5.0 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -1716,4 +1716,4 @@ main(int argc, char *argv[])
}
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_5_0beta29 your_png_h_is_not_version_1_5_0beta29;
+typedef version_1_5_0beta30 your_png_h_is_not_version_1_5_0beta30;
diff --git a/pngtrans.c b/pngtrans.c
index 6d9c28a55..b2adf77ef 100644
--- a/pngtrans.c
+++ b/pngtrans.c
@@ -1,7 +1,7 @@
/* pngtrans.c - transforms the data in a row (used by both readers and writers)
*
- * Last changed in libpng 1.5.0 [June 21, 2010]
+ * Last changed in libpng 1.5.0 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngwio.c b/pngwio.c
index 82835725e..784c0ef3b 100644
--- a/pngwio.c
+++ b/pngwio.c
@@ -1,7 +1,7 @@
/* pngwio.c - functions for data output
*
- * Last changed in libpng 1.5.0 [June 21, 2010]
+ * Last changed in libpng 1.5.0 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngwrite.c b/pngwrite.c
index fc6737c02..343e67027 100644
--- a/pngwrite.c
+++ b/pngwrite.c
@@ -1,7 +1,7 @@
/* pngwrite.c - general routines to write a PNG file
*
- * Last changed in libpng 1.5.0 [June 21, 2010]
+ * Last changed in libpng 1.5.0 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngwtran.c b/pngwtran.c
index 3b33d33d0..069a78290 100644
--- a/pngwtran.c
+++ b/pngwtran.c
@@ -1,7 +1,7 @@
/* pngwtran.c - transforms the data in a row for PNG writers
*
- * Last changed in libpng 1.5.0 [June 21, 2010]
+ * Last changed in libpng 1.5.0 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngwutil.c b/pngwutil.c
index fa2ccbc56..9ec817fbb 100644
--- a/pngwutil.c
+++ b/pngwutil.c
@@ -1,7 +1,7 @@
/* pngwutil.c - utilities to write a PNG file
*
- * Last changed in libpng 1.5.0 [June 21, 2010]
+ * Last changed in libpng 1.5.0 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index 0a74955c3..01d8ad262 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.5.0beta29 - June 21, 2010
+libpng version 1.5.0beta30 - June 22, 2010
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index e1e9d99b7..31f42a26b 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source and build
*
- * libpng version 1.5.0beta29 - June 21, 2010
+ * libpng version 1.5.0beta30 - June 22, 2010
*
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index b808e6f1b..ef9338970 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,9 +1,9 @@
-Makefiles for libpng version 1.5.0beta29 - June 21, 2010
+Makefiles for libpng version 1.5.0beta30 - June 22, 2010
pnglibconf.h => Stores configuration settings
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng15.so.15.1.5.0beta29)
+ (gcc, creates libpng15.so.15.1.5.0beta30)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -20,7 +20,7 @@ pnglibconf.h => Stores configuration settings
makefile.dec => DEC Alpha UNIX makefile
makefile.dj2 => DJGPP 2 makefile
makefile.elf => Linux/ELF makefile symbol versioning,
- gcc, creates libpng15.so.15.1.5.0beta29)
+ gcc, creates libpng15.so.15.1.5.0beta30)
makefile.freebsd => FreeBSD makefile
makefile.gcc => Generic gcc makefile
makefile.hpgcc => HPUX makefile using gcc
@@ -35,12 +35,12 @@ pnglibconf.h => Stores configuration settings
makefile.os2 => OS/2 Makefile (gcc and emx, requires libpng.def)
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
makefile.sggcc => Silicon Graphics (gcc,
- creates libpng15.so.15.1.5.0beta29)
+ creates libpng15.so.15.1.5.0beta30)
makefile.sgi => Silicon Graphics IRIX makefile (cc, creates static lib)
makefile.solaris => Solaris 2.X makefile (gcc,
- creates libpng15.so.15.1.5.0beta29)
+ creates libpng15.so.15.1.5.0beta30)
makefile.so9 => Solaris 9 makefile (gcc,
- creates libpng15.so.15.1.5.0beta29)
+ creates libpng15.so.15.1.5.0beta30)
makefile.std => Generic UNIX makefile (cc, creates static libpng.a)
makefile.sunos => Sun makefile
makefile.32sunu => Sun Ultra 32-bit makefile
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index 0ca6641c7..3d07ee5ef 100755
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
# Modeled after libxml-config.
-version=1.5.0beta29
+version=1.5.0beta30
prefix=""
libdir=""
libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index d759da3ff..7f598b29c 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@ includedir=@includedir@/libpng15
Name: libpng
Description: Loads and saves PNG files
-Version: 1.5.0beta29
+Version: 1.5.0beta30
Libs: -L${libdir} -lpng15
Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index f2a69a66a..877db5a91 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include/libpng15
LIB= png15
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.5.0beta29
+SHLIB_MINOR= 1.5.0beta30
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index 6b543cea4..098fd28f5 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include
LIB= png
SHLIB_MAJOR= 3
-SHLIB_MINOR= 1.5.0beta29
+SHLIB_MINOR= 1.5.0beta30
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index f482aa59d..d7f35af15 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@ LIBDIR= ${PREFIX}/lib
MANDIR= ${PREFIX}/man/cat
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.5.0beta29
+SHLIB_MINOR= 1.5.0beta30
LIB= png
SRCS= png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/options.awk b/scripts/options.awk
index 9286cd11a..9567d188e 100755
--- a/scripts/options.awk
+++ b/scripts/options.awk
@@ -1,7 +1,7 @@
#!/bin/awk -f
# scripts/options.awk - library build configuration control
#
-# last changed in libpng version 1.5.0 - June 21, 2010
+# last changed in libpng version 1.5.0 - June 22, 2010
#
# Copyright (c) 1998-2010 Glenn Randers-Pehrson
#
diff --git a/scripts/pnglibconf.dfa b/scripts/pnglibconf.dfa
index e8d7de5d6..9e6b93d77 100644
--- a/scripts/pnglibconf.dfa
+++ b/scripts/pnglibconf.dfa
@@ -6,7 +6,7 @@
#
com pnglibconf.h - library build configuration
com
-com libpng version PNGLIB_VERSION - last changed on June 21, 2010
+com libpng version PNGLIB_VERSION - last changed on June 22, 2010
com
com Copyright (c) 1998-2010 Glenn Randers-Pehrson
com
diff --git a/scripts/pnglibconf.h b/scripts/pnglibconf.h
index 6b97fe2ad..2aba80c24 100644
--- a/scripts/pnglibconf.h
+++ b/scripts/pnglibconf.h
@@ -1,7 +1,7 @@
-/* libpng-1.5.0beta29 STANDARD API DEFINITION */
+/* libpng-1.5.0beta30 STANDARD API DEFINITION */
/* pnglibconf.h - library build configuration */
-/* last changed in libpng version 1.5.0 - June 21, 2010 */
+/* last changed in libpng version 1.5.0 - June 22, 2010 */
/* Copyright (c) 1998-2010 Glenn Randers-Pehrson */
diff --git a/scripts/pngwin.def b/scripts/pngwin.def
index a918285a2..7576343b5 100644
--- a/scripts/pngwin.def
+++ b/scripts/pngwin.def
@@ -11,7 +11,7 @@ LIBRARY
;OS2 CODE PRELOAD MOVEABLE DISCARDABLE
EXPORTS
-;Version 1.5.0beta29
+;Version 1.5.0beta30
png_access_version_number @1
png_set_sig_bytes @2
png_sig_cmp @3
diff --git a/scripts/pngwin.dfn b/scripts/pngwin.dfn
index 016516e96..d08779263 100644
--- a/scripts/pngwin.dfn
+++ b/scripts/pngwin.dfn
@@ -1,7 +1,7 @@
/* pngwin.dfn - define format of pngwin.def
*
- * Last changed in libpng version 1.5.0 [June 21, 2010]
+ * Last changed in libpng version 1.5.0 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
*
* This code is released under the libpng license.
diff --git a/scripts/sym.dfn b/scripts/sym.dfn
index 21e0f848d..d092ee8aa 100644
--- a/scripts/sym.dfn
+++ b/scripts/sym.dfn
@@ -1,7 +1,7 @@
/* sym.dfn - define format of libpng.sym
*
- * Last changed in libpng version 1.5.0 [June 21, 2010]
+ * Last changed in libpng version 1.5.0 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
*
* This code is released under the libpng license.
diff --git a/scripts/symbols.def b/scripts/symbols.def
index 32bb3c02a..a71a80810 100644
--- a/scripts/symbols.def
+++ b/scripts/symbols.def
@@ -5,7 +5,7 @@
LIBRARY
EXPORTS
-;Version 1.5.0beta29
+;Version 1.5.0beta30
png_access_version_number @1
png_set_sig_bytes @2
png_sig_cmp @3
diff --git a/scripts/symbols.dfn b/scripts/symbols.dfn
index 33ebd3731..f1d07f56a 100644
--- a/scripts/symbols.dfn
+++ b/scripts/symbols.dfn
@@ -1,7 +1,7 @@
/* symbols.dfn - find all exported symbols
*
- * Last changed in libpng version 1.5.0 [June 21, 2010]
+ * Last changed in libpng version 1.5.0 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
*
* This code is released under the libpng license.
diff --git a/scripts/vers.dfn b/scripts/vers.dfn
index 874c279e6..290d4cbde 100644
--- a/scripts/vers.dfn
+++ b/scripts/vers.dfn
@@ -1,7 +1,7 @@
/* vers.dfn - define format of libpng.vers
*
- * Last changed in libpng version 1.5.0 [June 21, 2010]
+ * Last changed in libpng version 1.5.0 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
*
* This code is released under the libpng license.
diff --git a/png.c b/png.c
index bd065eb7d..7bdabe600 100644
--- a/png.c
+++ b/png.c
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
* Last changed in libpng 1.5.0 [June 21, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -14,7 +14,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_5_0beta29 Your_png_h_is_not_version_1_5_0beta29;
+typedef version_1_5_0beta30 Your_png_h_is_not_version_1_5_0beta30;
/* Version information for C files. This had better match the version
* string defined in png.h.
@@ -560,13 +560,13 @@ png_get_copyright(png_structp png_ptr)
#else
# ifdef __STDC__
return ((png_charp) PNG_STRING_NEWLINE \
- "libpng version 1.5.0beta29 - June 21, 2010" PNG_STRING_NEWLINE \
+ "libpng version 1.5.0beta30 - June 22, 2010" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2010 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE);
# else
- return ((png_charp) "libpng version 1.5.0beta29 - June 21, 2010\
+ return ((png_charp) "libpng version 1.5.0beta30 - June 22, 2010\
Copyright (c) 1998-2010 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.");
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
- * Last changed in libpng 1.5.0 [June 21, 2010]
+ * Last changed in libpng 1.5.0 [June 22, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/png.h b/png.h
index 43f0595de..a8b831173 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.0beta29 - June 21, 2010
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.0beta29 - June 21, 2010: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -140,7 +140,7 @@
* 1.4.1 14 10401 14.so.14.1[.0]
* 1.4.2 14 10402 14.so.14.2[.0]
* 1.4.3 14 10403 14.so.14.3[.0]
- * 1.5.0beta01-29 15 10500 15.so.15.0[.0]
+ * 1.5.0beta01-30 15 10500 15.so.15.0[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -172,7 +172,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.0beta29, June 21, 2010, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -284,13 +284,13 @@
* Y2K compliance in libpng:
* =========================
*
- * June 21, 2010
+ * June 22, 2010
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.5.0beta29 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -346,9 +346,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.0beta29"
+#define PNG_LIBPNG_VER_STRING "1.5.0beta30"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.0beta29 - June 21, 2010\n"
+ " libpng version 1.5.0beta30 - June 22, 2010\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -361,7 +361,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 29
+#define PNG_LIBPNG_VER_BUILD 30
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -836,7 +836,7 @@ typedef PNG_CALLBACK(void, *png_free_ptr, (png_structp, png_voidp),);
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_5_0beta29;
+typedef png_structp version_1_5_0beta30;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.0beta29 - June 21, 2010
+ * libpng version 1.5.0beta30 - June 22, 2010
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.0beta29 - June 21, 2010: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.0beta30 - June 22, 2010: Glenn
* See also "Contributing Authors", below.
*
@@ -172,7 +172,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.0beta29, June 21, 2010, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.0beta30, June 22, 2010, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -284,13 +284,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.5.0beta29 are Y2K compliant. It is my belief that earlier
+ * upward through 1.5.0beta30 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*